make_longlong2

Applicability

Product

Supported

Atlas 350 Accelerator Card

Atlas A3 training product/Atlas A3 inference product

x

Atlas A2 training product/Atlas A2 inference product

x

Atlas 200I/500 A2 inference product

x

Atlas inference product AI Core

x

Atlas inference product Vector Core

x

Atlas training product

x

Function Usage

Creates a longlong2 vector from two given long long int values.

Prototype

1
inline longlong2 make_longlong2(long long int x, long long int y)

Parameters

Table 1 Parameters

Parameter

Input/Output

Description

x

Input

Source operand.

y

Input

Source operand.

Returns

A new longlong2 vector consisting of the two long long int values

Restrictions

For SIMT programming, this API is not supported.

Header Files to Be Included

To use this API, the simt_api/vector_functions.h header file must be included.

1
#include "simt_api/vector_functions.h"

Examples

For SIMD and SIMT programming:
1
2
3
4
5
__global__ __launch_bounds__(1024) inline void kernel_make_longlong2(__gm__ longlong2* dst, __gm__ long long int* x, __gm__ long long int* y)
{
    int idx = threadIdx.x + blockIdx.x * blockDim.x;
    dst[idx] = make_longlong2(x[idx], y[idx]);
}